==> _private_core_network-0.0.40.tar.gz: lib/network_resources/model/home_attribute.dart <==
class HomeAttribute {
  int? id;
  dynamic maxPriceFormat;
  dynamic minPriceFormat;
  dynamic maxArea;
  dynamic minArea;
  String? sizeUnit;
  List<HomeAttributes>? attributes;

  HomeAttribute(
      {this.id,
      this.maxPriceFormat,
      this.minPriceFormat,
      this.maxArea,
      this.minArea,
      this.sizeUnit,
      this.attributes});

  HomeAttribute.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    maxPriceFormat = json["maxPriceFormat"];
    minPriceFormat = json["minPriceFormat"];
    maxArea = json["maxArea"];
    minArea = json["minArea"];
    sizeUnit = json["sizeUnit"];
    attributes = json["attributes"] == null
        ? null
        : (json["attributes"] as List)
            .map((e) => HomeAttributes.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["maxPriceFormat"] = maxPriceFormat;
    _data["minPriceFormat"] = minPriceFormat;
    _data["maxArea"] = maxArea;
    _data["minArea"] = minArea;
    _data["sizeUnit"] = sizeUnit;
    if (attributes != null) {
      _data["attributes"] = attributes?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  HomeAttribute copyWith({
    int? id,
    dynamic maxPriceFormat,
    dynamic minPriceFormat,
    dynamic maxArea,
    dynamic minArea,
    String? sizeUnit,
    List<HomeAttributes>? attributes,
  }) =>
      HomeAttribute(
        id: id ?? this.id,
        maxPriceFormat: maxPriceFormat ?? this.maxPriceFormat,
        minPriceFormat: minPriceFormat ?? this.minPriceFormat,
        maxArea: maxArea ?? this.maxArea,
        minArea: minArea ?? this.minArea,
        sizeUnit: sizeUnit ?? this.sizeUnit,
        attributes: attributes ?? this.attributes,
      );
}

class HomeAttributes {
  int? id;
  String? name;
  String? description;
  List<Collection>? collection;

  HomeAttributes({this.id, this.name, this.description, this.collection});

  HomeAttributes.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    name = json["name"];
    description = json["description"];
    collection = json["collection"] == null
        ? null
        : (json["collection"] as List)
            .map((e) => Collection.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["name"] = name;
    _data["description"] = description;
    if (collection != null) {
      _data["collection"] = collection?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  HomeAttributes copyWith({
    int? id,
    String? name,
    String? description,
    List<Collection>? collection,
  }) =>
      HomeAttributes(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        collection: collection ?? this.collection,
      );
}

class Collection {
  int? id;
  String? label;

  Collection({this.id, this.label});

  Collection.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    return _data;
  }

  Collection copyWith({
    int? id,
    String? label,
  }) =>
      Collection(
        id: id ?? this.id,
        label: label ?? this.label,
      );
}

==> _private_core_network-0.0.41.tar.gz: lib/network_resources/model/home_attribute.dart <==
class HomeFiltersAvailable {
  int? id;
  dynamic maxPriceFormat;
  dynamic minPriceFormat;
  dynamic maxArea;
  dynamic minArea;
  String? sizeUnit;
  List<HomeAttributes>? attributes;

  HomeFiltersAvailable(
      {this.id,
      this.maxPriceFormat,
      this.minPriceFormat,
      this.maxArea,
      this.minArea,
      this.sizeUnit,
      this.attributes});

  HomeFiltersAvailable.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    maxPriceFormat = json["maxPriceFormat"];
    minPriceFormat = json["minPriceFormat"];
    maxArea = json["maxArea"];
    minArea = json["minArea"];
    sizeUnit = json["sizeUnit"];
    attributes = json["attributes"] == null
        ? null
        : (json["attributes"] as List)
            .map((e) => HomeAttributes.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["maxPriceFormat"] = maxPriceFormat;
    _data["minPriceFormat"] = minPriceFormat;
    _data["maxArea"] = maxArea;
    _data["minArea"] = minArea;
    _data["sizeUnit"] = sizeUnit;
    if (attributes != null) {
      _data["attributes"] = attributes?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  HomeFiltersAvailable copyWith({
    int? id,
    dynamic maxPriceFormat,
    dynamic minPriceFormat,
    dynamic maxArea,
    dynamic minArea,
    String? sizeUnit,
    List<HomeAttributes>? attributes,
  }) =>
      HomeFiltersAvailable(
        id: id ?? this.id,
        maxPriceFormat: maxPriceFormat ?? this.maxPriceFormat,
        minPriceFormat: minPriceFormat ?? this.minPriceFormat,
        maxArea: maxArea ?? this.maxArea,
        minArea: minArea ?? this.minArea,
        sizeUnit: sizeUnit ?? this.sizeUnit,
        attributes: attributes ?? this.attributes,
      );
}

class HomeAttributes {
  int? id;
  String? name;
  String? description;
  List<Collection>? collection;

  HomeAttributes({this.id, this.name, this.description, this.collection});

  HomeAttributes.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    name = json["name"];
    description = json["description"];
    collection = json["collection"] == null
        ? null
        : (json["collection"] as List)
            .map((e) => Collection.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["name"] = name;
    _data["description"] = description;
    if (collection != null) {
      _data["collection"] = collection?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  HomeAttributes copyWith({
    int? id,
    String? name,
    String? description,
    List<Collection>? collection,
  }) =>
      HomeAttributes(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        collection: collection ?? this.collection,
      );
}

class Collection {
  int? id;
  String? label;

  Collection({this.id, this.label});

  Collection.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    return _data;
  }

  Collection copyWith({
    int? id,
    String? label,
  }) =>
      Collection(
        id: id ?? this.id,
        label: label ?? this.label,
      );
}
